@@ -19,13 +19,13 @@ ui <- fluidPage(
     ),
     mainPanel(
       ### REPORTER
-      shiny::tags$div(
-        teal.reporter::add_card_button_ui("addReportCard"),
-        teal.reporter::download_report_button_ui("downloadButton"),
-        teal.reporter::reset_report_button_ui("resetButton")
+      tags$div(
+        add_card_button_ui("addReportCard"),
+        download_report_button_ui("downloadButton"),
+        reset_report_button_ui("resetButton")
       ),
       ###
-      shiny::tags$br(),
+      tags$br(),
       tabsetPanel(
         id = "tabs",
         tabPanel("Plot", plotOutput("dist_plot")),
@@ -58,8 +58,8 @@ server <- function(input, output, session) {
   plot <- reactive({
     req(input$binwidth)
     x <- mtcars$mpg
-    ggplot2::ggplot(data = mtcars, ggplot2::aes(x = mpg)) +
-      ggplot2::geom_histogram(binwidth = input$binwidth)
+    ggplot(data = mtcars, aes(x = mpg)) +
+      geom_histogram(binwidth = input$binwidth)
   })
 
   output$dist_plot <- renderPlot({
@@ -80,7 +80,7 @@ server <- function(input, output, session) {
   })
 
   ### REPORTER
-  reporter <- teal.reporter::Reporter$new()
+  reporter <- Reporter$new()
   card_fun <- function(card = ReportCard$new(), comment) {
     if (input$tabs == "Plot") {
       card$append_text("My plot", "header2")
@@ -96,9 +96,9 @@ server <- function(input, output, session) {
     card
   }
 
-  teal.reporter::add_card_button_srv("addReportCard", reporter = reporter, card_fun = card_fun)
-  teal.reporter::download_report_button_srv("downloadButton", reporter = reporter)
-  teal.reporter::reset_report_button_srv("resetButton", reporter)
+  add_card_button_srv("addReportCard", reporter = reporter, card_fun = card_fun)
+  download_report_button_srv("downloadButton", reporter = reporter)
+  reset_report_button_srv("resetButton", reporter)
   ###
 }
 
@@ -113,7 +113,7 @@ ui <- fluidPage(
     ),
     mainPanel(
       ### REPORTER
-      teal.reporter::simple_reporter_ui("simpleReporter"),
+      simple_reporter_ui("simpleReporter"),
       ###
       tabsetPanel(
         id = "tabs",
@@ -147,8 +147,8 @@ server <- function(input, output, session) {
   plot <- reactive({
     req(input$binwidth)
     x <- mtcars$mpg
-    ggplot2::ggplot(data = mtcars, ggplot2::aes(x = mpg)) +
-      ggplot2::geom_histogram(binwidth = input$binwidth)
+    ggplot(data = mtcars, aes(x = mpg)) +
+      geom_histogram(binwidth = input$binwidth)
   })
 
   output$dist_plot <- renderPlot({
@@ -169,7 +169,7 @@ server <- function(input, output, session) {
   })
 
   ### REPORTER
-  reporter <- teal.reporter::Reporter$new()
+  reporter <- Reporter$new()
   card_fun <- function(card = ReportCard$new(), comment) {
     if (input$tabs == "Plot") {
       card$append_text("My plot", "header2")
@@ -185,7 +185,7 @@ server <- function(input, output, session) {
     card
   }
 
-  teal.reporter::simple_reporter_srv("simpleReporter", reporter = reporter, card_fun = card_fun)
+  simple_reporter_srv("simpleReporter", reporter = reporter, card_fun = card_fun)
   ###
 }
 
